from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, Float, File, String

Rna2Meme_V0_1_0 = CommandToolBuilder(tool="rna2meme", base_command=["rna2meme"], inputs=[ToolInput(tag="in_output_rna_motifs", input_type=Boolean(optional=True), prefix="-rna", doc=InputDocumentation(doc="Output RNA motifs (default).")), ToolInput(tag="in_output_dna_motifs", input_type=Boolean(optional=True), prefix="-dna", doc=InputDocumentation(doc="Output DNA motifs instead of RNA motifs.")), ToolInput(tag="in_seed_start", input_type=Int(optional=True), prefix="-seed_start", doc=InputDocumentation(doc="starting offset of seed in RNA sequence,\nset to 0 to treat entire sequence as seed;\ndefault: 0")), ToolInput(tag="in_seed_end", input_type=Int(optional=True), prefix="-seed_end", doc=InputDocumentation(doc="ending offset of seed in RNA sequence;\ndefault: 0")), ToolInput(tag="in_start", input_type=Int(optional=True), prefix="-start", doc=InputDocumentation(doc="starting offset in RNA sequence (inclusive);\nuse negative numbers to count from end;\ndefault: 1")), ToolInput(tag="in_ending_offset_rna", input_type=Int(optional=True), prefix="-end", doc=InputDocumentation(doc="ending offset in RNA sequence (inclusive);\nuse negative numbers to count from end;\ndefault: -1")), ToolInput(tag="in_count_assign_match", input_type=Int(optional=True), prefix="-match", doc=InputDocumentation(doc="count to assign to a match (complement)\nin the seed region\ndefault: 1")), ToolInput(tag="in_wobble", input_type=Float(optional=True), prefix="-wobble", doc=InputDocumentation(doc="count to assign to a U for a G, or a G for a U\nin the seed region\ndefault: 0.1")), ToolInput(tag="in_miss", input_type=Float(optional=True), prefix="-miss", doc=InputDocumentation(doc="count to assign to a non-match non-wobble\nin the seed region\ndefault: 0.01")), ToolInput(tag="in_other_count", input_type=Float(optional=True), prefix="-other_count", doc=InputDocumentation(doc="extra count added to match, wobble\nand misses in non-seed positions to reduce\ntheir contribution to the score;\ndefault: 0.5")), ToolInput(tag="in_bg", input_type=File(optional=True), prefix="-bg", doc=InputDocumentation(doc="file with background frequencies of letters;\ndefault: uniform background")), ToolInput(tag="in_pseudo", input_type=Int(optional=True), prefix="-pseudo", doc=InputDocumentation(doc="add <total pseudocounts> times letter\nbackground to each frequency; default: 0")), ToolInput(tag="in_output_logodds_pssm", input_type=Boolean(optional=True), prefix="-logodds", doc=InputDocumentation(doc="output the log-odds (PSSM) and frequency\n(PSPM) motifs; default: PSPM motif only")), ToolInput(tag="in_url", input_type=String(optional=True), prefix="-url", doc=InputDocumentation(doc="website for the motif; The FASTA ID is\nsubstituted for MOTIF_NAME; The first word\nafter the FASTA ID is substituted for\nMOTIF_AC; default: no url")), ToolInput(tag="in_var_14", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_add", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_and", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_default", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_ending", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_extra", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_file", input_type=File(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_21", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_set", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_starting", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_their", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_use", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_26", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_27", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_contribution", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_misses", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_negative", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_offset", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_the", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_to", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_total_pseudo_counts", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_with", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_zero", input_type=Int(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_added", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_assign", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_background", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_40", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_motifs", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_numbers", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_times", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_frequencies", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_instead", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_letter", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_non_seed", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_seed", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_a", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_count", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_in", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_of", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_positions", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_score", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_treat", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_u", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_entire", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_from", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_letters", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_60", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_non_match", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_62", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_for", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_non_wobble", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_sequence", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_as", input_type=String(), position=7, doc=InputDocumentation(doc="")), ToolInput(tag="in_g", input_type=String(), position=8, doc=InputDocumentation(doc=""))], outputs=[], container="quay.io/biocontainers/meme:5.3.0--py38pl526hc1f1133_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Rna2Meme_V0_1_0().translate("wdl")

